Django Live Server
==================

This is purely the implementation of the ``LiveServerTestCase`` code 
due out in Django 1.4. 

Details are here:

https://docs.djangoproject.com/en/dev/releases/1.4/#support-for-in-browser-testing-frameworks
https://code.djangoproject.com/changeset/17241

I make no claim at all to this code - it was written by people 
much smarter than I!